==> yauaa-5.14.1-sources.jar: nl/basjes/parse/useragent/PackagedRules.java <==
/*
 * Yet Another UserAgent Analyzer
 * Copyright (C) 2013-2019 Niels Basjes
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package nl.basjes.parse.useragent;

import java.util.Arrays;
import java.util.List;

public final class PackagedRules {
    public static final List<String> RULE_FILES_LIST = Arrays.asList(
        "UserAgents/Alcatel.yaml",
        "UserAgents/Amazon.yaml",
        "UserAgents/AmazonDevices.yaml",
        "UserAgents/Android.yaml",
        "UserAgents/AndroidDeviceOverrides.yaml",
        "UserAgents/Anonymized.yaml",
        "UserAgents/Apple.yaml",
        "UserAgents/AppleTypes.yaml",
        "UserAgents/AppleTypesBasic.yaml",
        "UserAgents/AppleWebview.yaml",
        "UserAgents/Apps.yaml",
        "UserAgents/Asus.yaml",
        "UserAgents/Bada.yaml",
        "UserAgents/BlackBerry.yaml",
        "UserAgents/BrokenUseragents.yaml",
        "UserAgents/CPUTypes.yaml",
        "UserAgents/Cubot.yaml",
        "UserAgents/EMailClients.yaml",
        "UserAgents/Facebook-OsMeta.yaml",
        "UserAgents/Facebook.yaml",
        "UserAgents/GameConsoles.yaml",
        "UserAgents/GeckoFirefox.yaml",
        "UserAgents/GoannaPaleMoon.yaml",
        "UserAgents/GoogleChrome.yaml",
        "UserAgents/GoogleChrome70.yaml",
        "UserAgents/GoogleFavicon.yaml",
        "UserAgents/GooglePixel.yaml",
        "UserAgents/Hackers-SQLInjections.yaml",
        "UserAgents/Hackers.yaml",
        "UserAgents/Huawei.yaml",
        "UserAgents/ISOLanguageCode-tests.yaml",
        "UserAgents/ISOLanguageCode.yaml",
        "UserAgents/KaiOS.yaml",
        "UserAgents/Konqueror.yaml",
        "UserAgents/LG.yaml",
        "UserAgents/Lenovo-Tests.yaml",
        "UserAgents/Linux.yaml",
        "UserAgents/MSEdge.yaml",
        "UserAgents/MSInternetExplorer.yaml",
        "UserAgents/Maxthon.yaml",
        "UserAgents/Meizu.yaml",
        "UserAgents/Mobile.yaml",
        "UserAgents/MobileBrand-rules.yaml",
        "UserAgents/MobileBrand-tests.yaml",
        "UserAgents/MobileBrands.yaml",
        "UserAgents/MobileBrowser-tests.yaml",
        "UserAgents/Mozilla-Testcases.yaml",
        "UserAgents/Nokia.yaml",
        "UserAgents/Opera.yaml",
        "UserAgents/OperatingSystemDeviceNames.yaml",
        "UserAgents/Oppo.yaml",
        "UserAgents/OtherOS.yaml",
        "UserAgents/Otter.yaml",
        "UserAgents/Robot-Imitators.yaml",
        "UserAgents/RobotBaseRules.yaml",
        "UserAgents/Robots-Bing.yaml",
        "UserAgents/Robots-Google.yaml",
        "UserAgents/Robots-PriceSpiders.yaml",
        "UserAgents/Robots.yaml",
        "UserAgents/Safari.yaml",
        "UserAgents/Samsung.yaml",
        "UserAgents/SecurityFlag.yaml",
        "UserAgents/SettopBox.yaml",
        "UserAgents/Sony.yaml",
        "UserAgents/SpecialBrowsers.yaml",
        "UserAgents/TV.yaml",
        "UserAgents/Tencent.yaml",
        "UserAgents/URL.yaml",
        "UserAgents/UUID.yaml",
        "UserAgents/Ubuntu-18.10-tests.yaml",
        "UserAgents/Ubuntu-tests.yaml",
        "UserAgents/Ubuntu.yaml",
        "UserAgents/UbuntuVersionLookups.yaml",
        "UserAgents/Vodafone.yaml",
        "UserAgents/Watches.yaml",
        "UserAgents/Wiko.yaml",
        "UserAgents/Windows.yaml",
        "UserAgents/WindowsCE.yaml",
        "UserAgents/WindowsDesktopLookups.yaml",
        "UserAgents/WindowsOEM-tests.yaml",
        "UserAgents/WindowsOEMCodes.yaml",
        "UserAgents/WindowsPhone.yaml",
        "UserAgents/WindowsPhoneLookups.yaml",
        "UserAgents/Xiaomi.yaml",
        "UserAgents/eBook.yaml"
    );

    public static List<String> getRuleFileNames() {
        return RULE_FILES_LIST;
    }
}

==> yauaa-5.15-sources.jar: nl/basjes/parse/useragent/PackagedRules.java <==
/*
 * Yet Another UserAgent Analyzer
 * Copyright (C) 2013-2020 Niels Basjes
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package nl.basjes.parse.useragent;

import java.util.Arrays;
import java.util.Collections;
import java.util.List;

public final class PackagedRules {
    public static final List<String> RULE_FILES_LIST = Collections.unmodifiableList(Arrays.asList(
        "UserAgents/Alcatel.yaml",
        "UserAgents/Amazon.yaml",
        "UserAgents/AmazonDevices.yaml",
        "UserAgents/Android.yaml",
        "UserAgents/AndroidDeviceOverrides.yaml",
        "UserAgents/Anonymized.yaml",
        "UserAgents/Apple.yaml",
        "UserAgents/AppleTypes.yaml",
        "UserAgents/AppleTypesBasic.yaml",
        "UserAgents/AppleWebview.yaml",
        "UserAgents/Apps.yaml",
        "UserAgents/Asus.yaml",
        "UserAgents/Bada.yaml",
        "UserAgents/BlackBerry.yaml",
        "UserAgents/BrokenUseragents.yaml",
        "UserAgents/CPUTypes.yaml",
        "UserAgents/Cubot.yaml",
        "UserAgents/EMailClients.yaml",
        "UserAgents/Electron.yaml",
        "UserAgents/Facebook-OsMeta.yaml",
        "UserAgents/Facebook.yaml",
        "UserAgents/GameConsoles.yaml",
        "UserAgents/GeckoFirefox.yaml",
        "UserAgents/GoannaPaleMoon.yaml",
        "UserAgents/GoogleChrome.yaml",
        "UserAgents/GoogleChrome70.yaml",
        "UserAgents/GoogleFavicon.yaml",
        "UserAgents/GooglePixel.yaml",
        "UserAgents/Hackers-SQLInjections.yaml",
        "UserAgents/Hackers.yaml",
        "UserAgents/Huawei.yaml",
        "UserAgents/ISOLanguageCode-tests.yaml",
        "UserAgents/ISOLanguageCode.yaml",
        "UserAgents/KaiOS.yaml",
        "UserAgents/Konqueror.yaml",
        "UserAgents/LG.yaml",
        "UserAgents/Lenovo-Tests.yaml",
        "UserAgents/Linux.yaml",
        "UserAgents/MSEdge.yaml",
        "UserAgents/MSInternetExplorer.yaml",
        "UserAgents/Maxthon.yaml",
        "UserAgents/Meizu.yaml",
        "UserAgents/Mobile.yaml",
        "UserAgents/MobileBrand-rules.yaml",
        "UserAgents/MobileBrand-tests.yaml",
        "UserAgents/MobileBrands.yaml",
        "UserAgents/MobileBrowser-tests.yaml",
        "UserAgents/Mozilla-Testcases.yaml",
        "UserAgents/Nokia.yaml",
        "UserAgents/Opera.yaml",
        "UserAgents/OperatingSystemDeviceNames.yaml",
        "UserAgents/Oppo.yaml",
        "UserAgents/OtherOS.yaml",
        "UserAgents/Otter.yaml",
        "UserAgents/Robot-Imitators.yaml",
        "UserAgents/RobotBaseRules.yaml",
        "UserAgents/Robots-Bing.yaml",
        "UserAgents/Robots-Google.yaml",
        "UserAgents/Robots-PriceSpiders.yaml",
        "UserAgents/Robots.yaml",
        "UserAgents/Safari.yaml",
        "UserAgents/Samsung.yaml",
        "UserAgents/SecurityFlag.yaml",
        "UserAgents/SettopBox.yaml",
        "UserAgents/Sony.yaml",
        "UserAgents/SpecialBrowsers.yaml",
        "UserAgents/TV.yaml",
        "UserAgents/Tencent.yaml",
        "UserAgents/URL.yaml",
        "UserAgents/UUID.yaml",
        "UserAgents/Ubuntu-18.10-tests.yaml",
        "UserAgents/Ubuntu-tests.yaml",
        "UserAgents/Ubuntu.yaml",
        "UserAgents/UbuntuVersionLookups.yaml",
        "UserAgents/Vodafone.yaml",
        "UserAgents/Watches.yaml",
        "UserAgents/Wiko.yaml",
        "UserAgents/Windows.yaml",
        "UserAgents/WindowsCE.yaml",
        "UserAgents/WindowsDesktopLookups.yaml",
        "UserAgents/WindowsOEM-tests.yaml",
        "UserAgents/WindowsOEMCodes.yaml",
        "UserAgents/WindowsPhone.yaml",
        "UserAgents/WindowsPhoneLookups.yaml",
        "UserAgents/Xiaomi.yaml",
        "UserAgents/eBook.yaml"
    ));

    public static List<String> getRuleFileNames() {
        return RULE_FILES_LIST;
    }
}
